==> org-lsst-ccs-config-definition-1.0.14-sources.jar: org/lsst/ccs/config/BootCommand.java <==
package org.lsst.ccs.config;

import org.lsst.ccs.bus.CommandExecutor;
import org.lsst.ccs.bus.Command;

/**
 * A Command object for CCS delivering data to be run to start a subsystem.
 * @author bamade
 */
// Date: 26/06/12

    //TODO : review use!
public class BootCommand  extends Command {
    private static final long serialVersionUID = 9028522241007700060L;
    private DeploymentDescriptor descriptor ;
    private String subsystemName ;
    private String configName ;
    private String tag ;
    private Object configurationData ;

    /**
     * creates a boot command
     * @param destination
     * @param subsystemName
     * @param configName
     * @param tag
     * @param configurationData
     */
    public BootCommand(String destination ,String subsystemName, String configName, String tag,
                       Object configurationData) {
        super("",null) ; //TODO: re-engineer that!
        this.setDestination(destination);
        this.subsystemName = subsystemName;
        this.configName = configName;
        this.tag = tag;
        this.configurationData = configurationData;
    }

    public DeploymentDescriptor getDescriptor() {
        return descriptor;
    }

    public void setDescriptor(DeploymentDescriptor descriptor) {
        this.descriptor = descriptor;
    }

    public String getSubsystemName() {
        return subsystemName;
    }

    public String getConfigName() {
        return configName;
    }

    public String getTag() {
        return tag;
    }

    public Object getConfigurationData() {
        return configurationData;
    }


    //@Override
    public Object execute(CommandExecutor s) {
       return null ;
    }
    @Override
    public String getMessageType() {
        return "lsst.bootCommand";
    }
}

==> org-lsst-ccs-config-definition-1.5.3-sources.jar: org/lsst/ccs/config/BootCommand.java <==
package org.lsst.ccs.config;

import org.lsst.ccs.bus.CommandExecutor;
import org.lsst.ccs.bus.Command;

/**
 * A Command object for CCS delivering data to be run to start a subsystem.
 * @author bamade
 */
// Date: 26/06/12

    //TODO : review use!
public class BootCommand  extends Command {
    private static final long serialVersionUID = 9028522241007700060L;
    private DeploymentDescriptor descriptor ;
    private String subsystemName ;
    private String configName ;
    private String tag ;
    private Object configurationData ;

    /**
     * creates a boot command
     * @param destination
     * @param subsystemName
     * @param configName
     * @param tag
     * @param configurationData
     */
    public BootCommand(String destination ,String subsystemName, String configName, String tag,
                       Object configurationData) {
        super("",0, destination,null) ; //TODO: re-engineer that!
        this.subsystemName = subsystemName;
        this.configName = configName;
        this.tag = tag;
        this.configurationData = configurationData;
    }

    public DeploymentDescriptor getDescriptor() {
        return descriptor;
    }

    public void setDescriptor(DeploymentDescriptor descriptor) {
        this.descriptor = descriptor;
    }

    public String getSubsystemName() {
        return subsystemName;
    }

    public String getConfigName() {
        return configName;
    }

    public String getTag() {
        return tag;
    }

    public Object getConfigurationData() {
        return configurationData;
    }


    //@Override
    public Object execute(CommandExecutor s) {
       return null ;
    }
    @Override
    public String getMessageType() {
        return "lsst.bootCommand";
    }
}
